@@ -1,6 +1,6 @@
 package Foo;
 our VERSION='1.234567';
-use 5.008_008;
+use v5.8.8;
 1
 __END__
 
